# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import pytz

from django.utils.translation import ugettext_lazy as _

CURRENCY_CHOICES = (
    ("USD", "$USD"),
    ("EUR", "€"),
    ("GBP", "£"),
    ("AUD", "$AUD"),
    ("CAD", "$CAD"),
    ("SGD", "$SGD"),
    ("HKD", "$HKD"),
    ("NZD", "$NZD"),
    ("MXN", "$MXN"),
    ("BRL", "R$"),
    ("CZK", "Kč"),
    ("DKK", "kr DKK"),
    ("SEK", "kr SEK"),
    ("NOK", "kr NOK"),
    ("HUF", "Ft"),
    ("ILS", "₪"),
    ("JPY", "¥"),
    ("MYR", "RM"),
    ("PHP", "Php"),
    ("PLN", "zł"),
    ("CHF", "CHF"),
    ("TWD", "NT$"),
    ("THB", "฿"),
)

CURRENCY_SYMBOLS = (
    ("USD", "$"),
    ("EUR", "€"),
    ("GBP", "£"),
    ("AUD", "$"),
    ("CAD", "$"),
    ("SGD", "$"),
    ("HKD", "$"),
    ("NZD", "$"),
    ("MXN", "$"),
    ("BRL", "R$"),
    ("CZK", "Kč"),
    ("DKK", "kr"),
    ("SEK", "kr"),
    ("NOK", "kr"),
    ("HUF", "Ft"),
    ("ILS", "₪"),
    ("JPY", "¥"),
    ("MYR", "RM"),
    ("PHP", "Php"),
    ("PLN", "zł"),
    ("CHF", "CHF"),
    ("TWD", "NT$"),
    ("THB", "฿"),
)

CURRENCY_TRIGRAMS = (
    ("USD", "USD"),
    ("AUD", "AUD"),
    ("CAD", "CAD"),
    ("SGD", "SGD"),
    ("HKD", "HKD"),
    ("NZD", "NZD"),
    ("MXN", "MXN"),
    ("DKK", "DKK"),
    ("SEK", "SEK"),
    ("NOK", "NOK"),
)

CURRENCY_LABELS = (
    ("USD", _("United States Dollar")),
    ("EUR", _("Euro")),
    ("GBP", _("British Pound")),
    ("AUD", _("Australian Dollar")),
    ("CAD", _("Canadian Dollar")),
    ("SGD", _("Singapore Dollar")),
    ("HKD", _("Hong Kong Dollar")),
    ("NZD", _("New Zealand Dollar")),
    ("MXN", _("Mexican Peso")),
    ("BRL", _("Brazilian Real")),
    ("CZK", _("Czech Koruna")),
    ("DKK", _("Danish Krone")),
    ("SEK", _("Swedish Krona")),
    ("NOK", _("Norwegian Krone")),
    ("HUF", _("Hungarian Forint")),
    ("ILS", _("Israeli Shekel")),
    ("JPY", _("Japanese Yen")),
    ("MYR", _("Malaysian Ringgit")),
    ("PHP", _("Philippine Peso")),
    ("PLN", _("Polish Zloty")),
    ("CHF", _("Swiss Franc")),
    ("TWD", _("Taiwan New Dollar")),
    ("THB", _("Thai Baht")),
)

CURRENCY_BY_COUNTRIES = (
    ("AF", "USD"),
    ("AX", "EUR"),
    ("AL", "USD"),
    ("DZ", "USD"),
    ("AS", "USD"),
    ("AD", "EUR"),
    ("AO", "USD"),
    ("AI", "USD"),
    ("AQ", "USD"),
    ("AG", "USD"),
    ("AR", "USD"),
    ("AM", "USD"),
    ("AW", "USD"),
    ("AU", "AUD"),
    ("AT", "EUR"),
    ("AZ", "USD"),
    ("BS", "USD"),
    ("BH", "USD"),
    ("BD", "USD"),
    ("BB", "USD"),
    ("BY", "USD"),
    ("BE", "EUR"),
    ("BZ", "USD"),
    ("BJ", "USD"),
    ("BM", "USD"),
    ("BT", "USD"),
    ("BO", "USD"),
    ("BA", "USD"),
    ("BW", "USD"),
    ("BV", "NOK"),
    ("BR", "BRL"),
    ("IO", "USD"),
    ("BN", "SGD"),
    ("BG", "USD"),
    ("BF", "USD"),
    ("BI", "USD"),
    ("KH", "USD"),
    ("CM", "USD"),
    ("CA", "CAD"),
    ("CV", "USD"),
    ("KY", "USD"),
    ("CF", "USD"),
    ("TD", "USD"),
    ("CL", "USD"),
    ("CN", "USD"),
    ("CX", "AUD"),
    ("CC", "AUD"),
    ("CO", "USD"),
    ("KM", "USD"),
    ("CG", "USD"),
    ("CD", "USD"),
    ("CK", "NZD"),
    ("CR", "USD"),
    ("CI", "USD"),
    ("HR", "USD"),
    ("CU", "USD"),
    ("CY", "EUR"),
    ("CZ", "CZK"),
    ("DK", "DKK"),
    ("DJ", "USD"),
    ("DM", "USD"),
    ("DO", "USD"),
    ("EC", "USD"),
    ("EG", "USD"),
    ("SV", "USD"),
    ("GQ", "USD"),
    ("ER", "USD"),
    ("EE", "EUR"),
    ("ET", "USD"),
    ("FK", "GBP"),
    ("FO", "DKK"),
    ("FJ", "USD"),
    ("FI", "EUR"),
    ("FR", "EUR"),
    ("GF", "EUR"),
    ("PF", "USD"),
    ("TF", "EUR"),
    ("GA", "USD"),
    ("GM", "USD"),
    ("GE", "USD"),
    ("DE", "EUR"),
    ("GH", "USD"),
    ("GI", "GBP"),
    ("GR", "EUR"),
    ("GL", "DKK"),
    ("GD", "USD"),
    ("GP", "EUR"),
    ("GU", "USD"),
    ("GT", "USD"),
    ("GG", "GBP"),
    ("GN", "USD"),
    ("GW", "USD"),
    ("GY", "USD"),
    ("HT", "USD"),
    ("HM", "AUD"),
    ("VA", "EUR"),
    ("HN", "USD"),
    ("HK", "HKD"),
    ("HU", "HUF"),
    ("IS", "USD"),
    ("IN", "USD"),
    ("ID", "USD"),
    ("IR", "USD"),
    ("IQ", "USD"),
    ("IE", "EUR"),
    ("IM", "GBP"),
    ("IL", "ILS"),
    ("IT", "EUR"),
    ("JM", "USD"),
    ("JP", "JPY"),
    ("JE", "GBP"),
    ("JO", "USD"),
    ("KZ", "USD"),
    ("KE", "USD"),
    ("KI", "AUD"),
    ("KP", "USD"),
    ("KR", "USD"),
    ("KW", "USD"),
    ("KG", "USD"),
    ("LA", "USD"),
    ("LV", "USD"),
    ("LB", "USD"),
    ("LS", "USD"),
    ("LR", "USD"),
    ("LY", "USD"),
    ("LI", "CHF"),
    ("LT", "USD"),
    ("LU", "EUR"),
    ("MO", "USD"),
    ("MK", "USD"),
    ("MG", "USD"),
    ("MW", "USD"),
    ("MY", "MYR"),
    ("MV", "USD"),
    ("ML", "USD"),
    ("MT", "EUR"),
    ("MH", "USD"),
    ("MQ", "EUR"),
    ("MR", "USD"),
    ("MU", "USD"),
    ("YT", "EUR"),
    ("MX", "MXN"),
    ("FM", "USD"),
    ("MD", "USD"),
    ("MC", "EUR"),
    ("MN", "USD"),
    ("ME", "EUR"),
    ("MS", "USD"),
    ("MA", "USD"),
    ("MZ", "USD"),
    ("MM", "USD"),
    ("NA", "USD"),
    ("NR", "AUD"),
    ("NP", "USD"),
    ("NL", "EUR"),
    ("AN", "USD"),
    ("NC", "USD"),
    ("NZ", "NZD"),
    ("NI", "USD"),
    ("NE", "USD"),
    ("NG", "USD"),
    ("NU", "NZD"),
    ("NF", "AUD"),
    ("MP", "USD"),
    ("NO", "NOK"),
    ("OM", "USD"),
    ("PK", "USD"),
    ("PW", "USD"),
    ("PS", "ILS"),
    ("PA", "USD"),
    ("PG", "USD"),
    ("PY", "USD"),
    ("PE", "USD"),
    ("PH", "PHP"),
    ("PN", "NZD"),
    ("PL", "PLN"),
    ("PT", "EUR"),
    ("PR", "USD"),
    ("QA", "USD"),
    ("RE", "EUR"),
    ("RO", "USD"),
    ("RU", "USD"),
    ("RW", "USD"),
    ("BL", "EUR"),
    ("SH", "GBP"),
    ("KN", "USD"),
    ("LC", "USD"),
    ("MF", "EUR"),
    ("PM", "EUR"),
    ("VC", "USD"),
    ("WS", "USD"),
    ("SM", "EUR"),
    ("ST", "USD"),
    ("SA", "USD"),
    ("SN", "USD"),
    ("RS", "USD"),
    ("SC", "USD"),
    ("SL", "USD"),
    ("SG", "SGD"),
    ("SK", "EUR"),
    ("SI", "EUR"),
    ("SB", "USD"),
    ("SO", "USD"),
    ("ZA", "USD"),
    ("GS", "GBP"),
    ("ES", "EUR"),
    ("LK", "USD"),
    ("SD", "USD"),
    ("SR", "USD"),
    ("SJ", "NOK"),
    ("SZ", "USD"),
    ("SE", "SEK"),
    ("CH", "CHF"),
    ("SY", "USD"),
    ("TW", "TWD"),
    ("TJ", "USD"),
    ("TZ", "USD"),
    ("TH", "THB"),
    ("TL", "USD"),
    ("TG", "USD"),
    ("TK", "NZD"),
    ("TO", "USD"),
    ("TT", "USD"),
    ("TN", "USD"),
    ("TR", "USD"),
    ("TM", "USD"),
    ("TC", "USD"),
    ("TV", "AUD"),
    ("UG", "USD"),
    ("UA", "USD"),
    ("AE", "USD"),
    ("GB", "GBP"),
    ("US", "USD"),
    ("UM", "USD"),
    ("UY", "USD"),
    ("UZ", "USD"),
    ("VU", "USD"),
    ("VE", "USD"),
    ("VN", "USD"),
    ("VG", "USD"),
    ("VI", "USD"),
    ("WF", "USD"),
    ("EH", "USD"),
    ("YE", "USD"),
    ("ZM", "USD"),
    ("ZW", "USD"),
)

TIMEZONE_CHOICES = sorted(
    ((tz, tz) for tz in pytz.common_timezones), key=lambda x: x[1]
)

TIME_ZONE = "Europe/Paris"
